% La fonction "Euler" simule notre EDS sur [0,"T"], en prenant comme
% condition initiale "x0" pour X et "yO" pour Y.
function xt = Euler (x0, y0, T)
% Paramètres de la simulation : variance du bruit pas unité de temps et
% nombre de pas de discrétisation choisi.
VAR_BRUIT = [1 1; 1 2];
NPAS = 2000;
% Ampleur du pas de temps, noté "dt".
dt = T / NPAS;
% On calcule une fois pour toutes la matrice de Cholesky, appelée "sigma".
% Notez la transposition, pour tenir compte de la convention de Matlab sur
% la décomposition de Cholesky.
sigma = chol (VAR_BRUIT)';
% Ici je ne fais que le calcul de la simulation ; je vous laisse ajouter
% les lignes qu'il faut pour obtenir un tracé ou renvoyer la valeur
% terminale de X.
xt = x0;
yt = y0;
for i = 1: NPAS
    % On simule le vecteur (dW_1, dW_2), appelé "bruit" (vu comme un
    % vecteur-colonne). On a utilisé pour ce faire la syntaxe « randn(2,1)
    % », qui produit une matrice 2×1 (càd. un 2-vecteur colonne) dont
    % toutes les cases sont des lois normales standard, indépendantes les
    % unes des autres.
    bruit = sigma * randn (2, 1) * sqrt (dt);
    % On simule les nouvelles valeurs de xt et yt (qu'on appelle "xt_" et
    % "yt_", exclusivement à partir des anciennes valeurs.
    xt_ = xt + yt * bruit(1);
    yt_ = yt + xt * bruit(2);
    % Maintenant on met les valeurs à jour.
    xt = xt_;
    yt = yt_;
end
return
end
